#include <string.h>
#include "parser.h"

#include "combinat.h"
#include "error_message.h"
#include "gparams.h"
#include "nu_sign_set.h"
#include "scan.h"
#include "startopt.h"
#include "statearray.h"
#include "runtime_options.h"

int main(int argc, char **argv){

  params_p params;
  int i,j;
  int tok;
  int non_zeros=0;
  int delete_count=0;
  int *delete,*delete_in,*old_label,*new_label;

  int *indices;
  
  params=malloc(sizeof(params_t));

  ro_process_args(argc,argv,params,SO_nonuniform);
  if (!parse_input(params))
    exit(0);
  
  /* do not output boundary */
  params->output_level &= ~1;

  if (strlen(params->delete)==0)
    err_fatal(HERE,"no deleted elements specified");

  delete_in=calloc(params->n,sizeof(int));

  scan_scan_string(params->delete);

  while((tok=scanlex())>0){
    switch(tok){
    case SCAN_INT:
      delete_in[delete_count++]=scanint;
      break;
    default:
      fprintf(stderr,"syntax:  %s -D'n1 n2 n3'\n",argv[0]);
      
    }
  }

  delete=calloc(delete_count,sizeof(int));
  bucket_sort(params->n,delete_count,delete_in,delete);
  old_label=calloc(params->n-delete_count+1,sizeof(int));
  new_label=calloc(params->n-delete_count+1,sizeof(int));

  j=1;
  old_label[0]=new_label[0]=-1;
  
  for (i=1; i<=params->n; i++){
    if (!set_contains(delete_count,delete,i)){
      old_label[j]=i;
      new_label[i]=j;
      j++;
    } else {
      new_label[i]=0;
    }
    
  }

  for (i=1; i<= params->n;i++){
    printf("# %d => %d \n",i,new_label[i]);
  }

  indices=calloc(params->r,sizeof(int));
  
  printf("rank=%d\nelements=%d\n",params->r,params->n-delete_count);
  printf("chirotope={");
  for (i=0; i <nss_count(parser.basis_signs); i++){
    int bindex;
    nu_sign_t sigma;
    nu_signed_index_t si=nss_next(parser.basis_signs);
    
    bindex=nsi_index(si);
    sigma=nsi_sign(si);

    which_kset(params->n,params->r,bindex,indices);

    if (!set_intersect(params->r,indices,delete_count,delete,NULL)){
      if (sign_intersection(sigma,SIGN_NONZERO))
	non_zeros++;
      printf("([");
      for (j=0; j<params->r ; j++){
	printf("%d ",new_label[indices[j]]);
      }
      printf("],%d)\n",sign2int(sigma));
    }
  }
  printf("}\n");
  if (non_zeros==0){
    err_warning(HERE,"No non zero bases remaining. Rank is incorrect");
  }

  return 0;
}


