/**
 * @file   extract_boundary.c
 * @author David Bremner <bremner@unb.ca>
 * @date   Sat Jun 15 16:23:32 2002
 * 
 * @brief  grab the boundary from an mpc input file
 * 
 * 
 */

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <assert.h>
#include "parser.h"
#include "gparams.h"
#include "error_message.h"
#include "output.h"
#include "facet_list.h"

static void usage(char ** argv){
  fprintf(stderr,"usage: %s: [options] n n n\n",argv[0]);
  fprintf(stderr,"\nInput/Output:\n");
  fprintf(stderr,"-i <file>\ttake input from <file>\n");
  fprintf(stderr,"-o <file>\twrite input to <file>\n");
}

int main(int argc, char** argv){
  int c;
  int n,r;
  int num_bases;
  int *chi_modified,*bdy_modified;

  int i;
  int facets;
  sa_array_p chi,bdy;
  facet_p F;

  int bdy_zero=-1,chi_zero=-1;
  
  params_p params=malloc(sizeof(params_t));
  ro_init(params);
  while((c=getopt(argc,argv,"i:o:C:B:b:"))!=-1){
    switch(c){
    case 'i':
      freopen(optarg,"r",stdin);
      assert(stdin);
      break;
    case 'o':
      freopen(optarg,"w",stdout);
      assert(stdout);
      break;
    default:
      usage(argv);
      exit(1);

    }
  }

  parse_input(params);

  n=params->n;
  r=params->r;

  printf("%d,%d\n",n,r);

  for (F=fl_first(parser.facets); F; F=fl_next(parser.facets)){
    int j;
    if (F->encoding==basis_index){
      output_kset(F->elements,F->rank,F->index_set[0]);
    } else {
      for(j=0; j<F->size; j++){
	printf("%d ",F->index_set[j]);
      }
    }
    printf("\n"); 
  }
  
  return(0);
}

