
#ifndef _OMS_ERROR_H
#define _OMS_ERROR_H 1

#include <stdarg.h>
#include <stdio.h>
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define ERR_INDENT_STR "*"

/* 
 * Preprocessor sillyness to define a macro HERE that points to the 
 * current file and line number
 */

#define __here(l) __FILE__ ":" #l
#define _here(l) __here(l)
#define HERE _here(__LINE__)

#define TRAP_NULL(p) if (p==NULL){ perror(HERE); abort(); };

#ifndef OMS_DEBUGLEVEL
#define OMS_DEBUGLEVEL 0
#endif

#if OMS_DEBUGLEVEL>=0
#define DEBUG0(a) oms_warning##a
#else 
#define DEBUG0(a) /**/
#endif



#if OMS_DEBUGLEVEL>=1
#define DEBUG1(a) oms_warning##a
#else 
#define DEBUG1(a) /**/
#endif

#if OMS_DEBUGLEVEL>=2
#define DEBUG2(a) oms_warning##a
#else 
#define DEBUG2(a) /**/
#endif

#if OMS_DEBUGLEVEL>=3
#define DEBUG3(a) oms_warning##a
#else 
#define DEBUG3(a) /**/
#endif

#if OMS_DEBUGLEVEL>=4
#define DEBUG4(a) oms_warning##a
#else 
#define DEBUG4(a) /**/
#endif

#if OMS_DEBUGLEVEL>=5
#define DEBUG5(a) oms_warning##a
#else 
#define DEBUG5(a) /**/
#endif

#if OMS_DEBUGLEVEL>=6
#define DEBUG6(a) oms_warning##a
#else 
#define DEBUG6(a) /**/
#endif

#define oms_debug(n,a) DEBUG ## n(a)

#if OMS_DEBUGLEVEL > 0 
extern int zzrval;
#define DEBUG_TAB debug_indent++
#define DEBUG_UNTAB debug_indent--
#define db_wrap(e) debug_indent++,zzrval=e,debug_indent--,zzrval
#else
#define DEBUG_TAB
#define DEBUG_UNTAB
#define db_wrap(e) e;
#endif



void oms_fatal(char *where,char *fmt, ...);
void oms_warning( char *where, char *fmt, ...);

#ifndef OMS_NDEBUG
#define oms_assert1(loc,EX) EX ? ((void)0) :oms_fatal(loc, "assertion failed: %s",#EX)
#define oms_assert(EX) oms_assert1(HERE,EX)
#else 
#define oms_assert1(loc,EX) ((void)0)
#define oms_assert(EX) ((void)0)
#endif

#define RETURN(x) {bool r=(x); oms_debug(5,(HERE,"returning %d",r)); DEBUG_UNTAB; return r; }
#define VOID_RETURN { DEBUG_UNTAB; return ; }


extern int debug_indent;
#endif

